% updated_dispersal.m
%
% surviving adults disperse
%
% Created 06/22/2015 JH
% Updated 06/29/2015 JH

% all the birds leave the habitat
BIRD(t, :) = zeros(1, L_size);                      
% ranks birds from largest to smallest
[bird_sizes, order_sizes] = sort(BIRD_IDENTITIES(:,gg + 3),'descend');
% chooses the number of birds to disperse (at most L_size)
    % assignable_birds = min(dispersal_population(t), L_size);
    assignable_birds = dispersal_population(t);
% preconditioning 
home_patches = zeros(assignable_birds, 1);
if (search == 1)
    neighbor_patches = zeros(assignable_birds, size(INA, 2));
elseif (search == 2)
    neighbor_patches = zeros(assignable_birds, size(INB, 2));
elseif(search == 3)
    neighbor_patches = zeros(assignable_birds, size(INC, 2));    
elseif (search == 4)
    neighbor_patches = zeros(assignable_birds, size(IND, 2));
end
searchable_patches = zeros(assignable_birds, mm); 
bird_location = zeros(assignable_birds, 1);
count_source_float = 0;
count_sink_float = 0;
c_count_source_float = 0;
c_count_sink_float = 0;
vv = 0;
ww = 0;
size_floaters_forest = 0;
size_floaters_coffee = 0;

for kk = 1 : assignable_birds;
    % finds the patches to which birds are currently assigned
    home_patches(kk) = BIRD_IDENTITIES(order_sizes(kk), hh + 3);
    % assigns floaters a random patch if they are an assignable bird
        if (home_patches(kk) < 0)
            home_patches(kk) = randsample(L_size, 1);
        end
    % finds the patches in the nearest distance
    if (search == 1)
        neighbor_patches(kk, :) = INA(home_patches(kk), :);
        % randomly selects mm patches to search, but home patch is first
        searchable_patches(kk, :) = [home_patches(kk) ... 
            randsample(INA(home_patches(kk), 2 : size(INA, 2)), mm - 1)];
    elseif (search == 2)
        neighbor_patches(kk, :) = INB(home_patches(kk), :);
        % randomly selects mm patches to search, but home patch is first
        searchable_patches(kk, :) = [home_patches(kk) ... 
            randsample(INB(home_patches(kk), 2 : size(INB, 2)), mm - 1)];
    elseif (search == 3)
        neighbor_patches(kk, :) = INC(home_patches(kk), :);
        % randomly selects mm patches to search, but home patch is first
        searchable_patches(kk, :) = [home_patches(kk) ... 
            randsample(INC(home_patches(kk), 2 : size(INC, 2)), mm - 1)];
    elseif (search == 4)
        neighbor_patches(kk, :) = IND(home_patches(kk), :);
        % randomly selects mm patches to search, but home patch is first
        searchable_patches(kk, :) = [home_patches(kk) ... 
            randsample(IND(home_patches(kk), 2 : size(IND, 2)), mm - 1)];
    end
    
    % variables to be used in the ifelseif statement below
    move_patch_found = 0;
    jj = 1;
    while (jj <=mm)
        if (preferred_habitat == 0)
            % patch searched must be empty 
            if(move_patch_found == 0 && ...
                    BIRD(t, searchable_patches(kk, jj)) == 0)
                move_patch_found = 1;       % stops the while loop
                BIRD(t, searchable_patches(kk, jj)) = 1; % for counting later
                bird_location(kk) = searchable_patches(kk, jj); % assignment made
                BIRD_IDENTITIES(order_sizes(kk), hh + 6) = bird_location(kk);
            end
            jj = jj + 1;
        elseif (preferred_habitat == 1)
            % patch searched must be empty
            if(move_patch_found == 0 && ...
                    BIRD(t, searchable_patches(kk, jj)) == 0)
                % patch must be a source OR the last search patch 
                if (SOURCE(1, searchable_patches(kk, jj)) == 1 || jj == mm)
                    move_patch_found = 1;   % stops the while loop
                    BIRD(t, searchable_patches(kk, jj)) = 1;    % for counting
                    bird_location(kk) = searchable_patches(kk, jj); %assignment made
                    BIRD_IDENTITIES(order_sizes(kk), hh + 6) = bird_location(kk);
                end  
            end
             jj = jj +1;
             
        elseif (preferred_habitat == 2)
            % patch must be empty 
            if(move_patch_found == 0 && ...
                    BIRD(t, searchable_patches(kk, jj)) == 0)
                % patch must be a sink OR the last search patch
                if (SOURCE(1, searchable_patches(kk, jj)) == 0 || jj == mm)
                    move_patch_found = 1;
                    BIRD(t, searchable_patches(kk, jj)) = 1;
                    bird_location(kk) = searchable_patches(kk, jj);
                    BIRD_IDENTITIES(order_sizes(kk), hh + 6) = bird_location(kk);
                end
            end
            jj = jj + 1;
        elseif (preferred_habitat == 3)
            % patch must be empty 
            if(move_patch_found == 0 && ...
                    BIRD(t, searchable_patches(kk, jj)) == 0)
                % patch must have the desired cover OR be empty
                if (CANOPY(1, searchable_patches(kk, jj))...
                        >= preferred_cover || jj == mm)
                    move_patch_found = 1;
                    BIRD(t, searchable_patches(kk, jj)) = 1;
                    bird_location(kk) = searchable_patches(kk, jj);
                    BIRD_IDENTITIES(order_sizes(kk), hh + 6) = bird_location(kk);
                end
            end
            jj = jj + 1;
        end
    end
        % any bird that did not find a patch is given floater patch
        if (bird_location(kk) == 0)
            bird_location(kk) = -1;
            BIRD_IDENTITIES(order_sizes(kk), hh + 6) = -1;
        end
             
    % new weights are assigned from these new patches
    if (bird_location(kk) >=1)
        if (SOURCE(1, bird_location(kk)) == 1)      % source birds
            BIRD_IDENTITIES(order_sizes(kk),gg + 6) = ...
                normrnd(weight_source_mean, weight_source_sd)/...
                BIRD_IDENTITIES(order_sizes(kk),2);
        
        elseif (SOURCE(1, bird_location(kk)) == 0)  % sink birds
            BIRD_IDENTITIES(order_sizes(kk),gg + 6) = ...
                normrnd(weight_sink_mean, weight_sink_sd)/...
                BIRD_IDENTITIES(order_sizes(kk),2);
        end
    elseif (bird_location(kk) == -1)                % floaters
            BIRD_IDENTITIES(order_sizes(kk), gg + 6) = ...
                normrnd(weight_floater_mean, weight_floater_sd)/...
                BIRD_IDENTITIES(order_sizes(kk),2);
            FLOATER(t, 1) = FLOATER(t, 1) + 1;
            float = rand(1);

            if (float <= prop_source)
               BIRD_IDENTITIES(order_sizes(kk), hh + 6) = -2; 
            else
               BIRD_IDENTITIES(order_sizes(kk), hh + 6) = -3; 

            end
    end
end

% parameters for next year's winter:
adults(t + 1) = length(BIRD_IDENTITIES(:, gg + 6));