% non-breeding season
% determines surviving population for dispersal
%
% Checked 06/17/2015 JH

juveniles(t) = post_breeding_population(t) - adults(t);
% juveniles(t) = post_breeding_population(t) - adults(t+1);
juveniles(t) = max(juveniles(t),0);
remove_adults = zeros(1);
remove_juveniles = zeros(1);
remove_birds = zeros(1);

% determine probability of survival for floaters
if (t>2)
    floater_density(t) = (FLOATER(t-1)/L_size);

if (floater_density(t) < floater_cc)
    psF(t) = psA;
elseif (floater_density(t) >= floater_cc && floater_density(t) <= floater_max)
    psF(t) = -(psA + 1)^((floater_density(t) - floater_cc)/...
        (floater_max - floater_cc)) + psA + 1;
elseif (floater_density(t) > floater_max)
    psF(t) = 0;
end
else
    psF(t) = psA;
end

% kills adults

prob_bird = rand(1, adults(t));             % generates random numbers for 
                                            % every adult in the system
for kk = 1 : adults(t); 
                                            % if the probability is lower
                                            % than the survival rate AND
                                            % the patch is non-empty
    if (prob_bird(kk) <= (1-psA) && ...
            BIRD_IDENTITIES(kk, gg + 3)~=0 && ...
            BIRD_IDENTITIES(kk, hh + 3)> 0)
        
        remove_adults(kk) = kk;
        BIRD_IDENTITIES(kk, gg + 3) = 0;            % kill the bird
        BIRD(t, BIRD_IDENTITIES(kk, hh + 3)) = 0;   % remove it from BIRD 
    end
    
    % kills floaters
    if (prob_bird(kk) <= (1-psF(t)) && ...
        BIRD_IDENTITIES(kk, gg + 3)~=0 && ...
        BIRD_IDENTITIES(kk, hh + 3)< 0)
        
        remove_floaters(kk) = kk;
        BIRD_IDENTITIES(kk, gg + 3) = 0;            % kill the bird
    end
    
end

% dying juveniles
prob_juv = rand(1, juveniles(t));           % generates random numbers for 
                                            % every juvenile in the system
for kk = 1 : juveniles(t);
    if (prob_juv(kk) <= (1- psJ))           % determines the juveniles that 
                                            % are to be killed
        remove_juveniles(kk) = kk + adults(t); 
                                            % kills juveniles
        BIRD_IDENTITIES(kk + adults(t), gg + 3) = 0;
    end
end

% bird identities will reflect the surviving juveniles for each breeding adult
for k = 1: adults(t);
    rj = 0;
    for jj = adults(t) + 1 : post_breeding_juveniles(t);
                                                % if the juvenile is alive
                                                % AND it has the same patch
                                                % as an adult, we track it
            if (BIRD_IDENTITIES(jj, gg + 3) ~= 0 && ...
                    BIRD_IDENTITIES(k, hh + 3)>0 && ...
                    BIRD_IDENTITIES(jj, hh + 3) == BIRD_IDENTITIES(k, hh + 3))
                rj = rj + 1;
            end
    end

    BIRD_IDENTITIES(k, ff + 3) = rj;
end


% remove the dead juveniles from BIRD_IDENTITIES

remove_juveniles(remove_juveniles == 0) = [];       % patches that have dead juveniles
remove_juveniles = sort(remove_juveniles', 'descend');      
                                                    % removes the rows
for kk = 1:length(remove_juveniles);    
    BIRD_IDENTITIES(remove_juveniles(kk), :) = [];
end

% total birds left for dispersal
dispersal_population(t) = length(find(BIRD_IDENTITIES(:, gg + 3)));

